@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+import threading
 import time
 
 from . import communications
@@ -7,6 +9,7 @@ __all__ = ['LocalCommunicator']
 
 
 class LocalCommunicator(communications.CommunicatorHelper):
+
     def task_send(self, msg):
         return self.fire_task(msg)
 
@@ -16,10 +19,9 @@ class LocalCommunicator(communications.CommunicatorHelper):
     def broadcast_send(self, body, sender=None, subject=None, correlation_id=None):
         return self.fire_broadcast(body, sender=sender, subject=subject, correlation_id=correlation_id)
 
-    def await(self, future=None, timeout=None):
-        if not future.done():
-            time.sleep(timeout)
-        try:
-            return future.result()
-        except futures.InvalidStateError:
+    def wait_for(self, future, timeout=None):
+        event = threading.Event()
+        future.add_done_callback(lambda _: event.set())
+
+        if not event.wait(timeout):
             raise communications.TimeoutError("Timed out waiting for result")
